# -*- coding: utf-8 -*-

# :copyright: (c) 2011 - 2014 by Arezqui Belaid.
# :license: MPL 2.0, see COPYING for more details.

__version__ = '0.3.0'
__author__ = "Arezqui Belaid"
__contact__ = "info@star2billing.com"
__homepage__ = "http://www.star2billing.org"
__docformat__ = "restructuredtext"
